#!/usr/bin/ruby
#--
#-------------------------------------------------------------------------------
#++
#
#= Introduction
#
#== Name:   checkjob.rb
#
#== Author: Tony Smith	<tony@perforce.com>
#
#== Description
#
#     Example trigger to ensure that all changelists being
#     submitted have at least one job associated.
#		  
#== Requires
#     Ruby
#     P4Ruby
#     P4Triggers module
#
#== Example 'triggers' section
#
#     Triggers:
#        checkjob change-submit //...  "ruby checkjob.rb %changelist%"
#
#== Note
#
#     For triggers I recommend you use a P4CONFIG file rather than hard coding
#     username/password in the script itself. This script assumes you've taken
#     that advice.
#
#== License
#
#  Copyright (c) 1997-2008, Perforce Software, Inc.  All rights reserved.
#  
#  Redistribution and use in source and binary forms, with or without
#  modification, are permitted provided that the following conditions are met:
#  
#  1.  Redistributions of source code must retain the above copyright
#  notice, this list of conditions and the following disclaimer.
#  
#  2.  Redistributions in binary form must reproduce the above copyright
#  notice, this list of conditions and the following disclaimer in the
#  documentation and/or other materials provided with the distribution.
#  
#  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
#  ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE SOFTWARE, INC. BE LIABLE FOR ANY
#  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
#  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
#  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
#  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
#  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#  
#--
#-------------------------------------------------------------------------------
#++
$:.unshift( File.dirname( __FILE__ ) )
require "P4"
require "P4Triggers"

#
# The trigger class itself. The main method in here is validate() which
# is invoked from the super-class' parse_change() method.
#
class JobTrigger < P4Trigger

    #
    # The error message we give to the user
    #
    @@USER_MESSAGE = 
    "\n\n" 								+
    "Your submission has been rejected because there are no jobs\n"	+
    "associated with this change. Please associate a job with this \n"	+
    "changelist and try again\n\n"

    # Do the enforcement.
    def validate()
	if ( change.jobs.length() == 0 )
	    message( @@USER_MESSAGE )
	    return false
	end
	return true
    end

end

#--
#-------------------------------------------------------------------------------
# Start of main script execution
#-------------------------------------------------------------------------------
#++

# By this stage it's pretty simple. Even argument validation is handled by
# the P4Trigger class so we don't even need to check that we were passed
# a changelist number.
jt = JobTrigger.new
exit( jt.parse_change( ARGV.shift ) )
